@@ -53,6 +53,8 @@ struct _HCPWindowPrivate
   GtkWidget      *large_icons_menu_item;
   GtkWidget      *small_icons_menu_item;
 
+  gboolean        device_locked;
+
   /* For state save data */
   gint            icon_size;
   gchar          *saved_focused_filename;
@@ -330,7 +332,8 @@ hcp_window_retrieve_configuration (HCPWindow *window)
   GConfClient *client = NULL;
   GError *error = NULL;
   gboolean icon_size;
-
+  gint lock_state;
+  
   g_return_if_fail (window);
   g_return_if_fail (HCP_IS_WINDOW (window));
 
@@ -354,6 +357,12 @@ hcp_window_retrieve_configuration (HCPWindow *window)
     priv->icon_size = icon_size ? TRUE : FALSE;
   }
 
+  lock_state = gconf_client_get_int (client,
+                                     HCP_GCONF_LOCK_STATE_KEY,
+                                     &error);
+
+  priv->device_locked = (lock_state > 0);
+ 
   g_object_unref (client);
 }
 
@@ -486,7 +495,8 @@ hcp_window_clear_user_data (GtkWidget *widget, HCPWindow *window)
   hcp_rfs (HCP_CUD_WARNING,
            HCP_CUD_WARNING_TITLE,
            HCP_CUD_SCRIPT,
-           HCP_CUD_HELP_TOPIC);
+           HCP_CUD_HELP_TOPIC,
+	   window->priv->device_locked);
 
   return TRUE;
 }
@@ -497,7 +507,8 @@ hcp_window_reset_factory_settings (GtkWidget *widget, HCPWindow *window)
   hcp_rfs (HCP_RFS_WARNING,
            HCP_RFS_WARNING_TITLE,
            HCP_RFS_SCRIPT,
-           HCP_RFS_HELP_TOPIC);
+           HCP_RFS_HELP_TOPIC,
+	   window->priv->device_locked);
 
   return TRUE;
 }
